You are viewing a plain text version of this content. The canonical link for it is here.
Posted to axis-cvs@ws.apache.org by he...@apache.org on 2005/05/12 14:32:58 UTC

svn commit: r169807 [2/3] - in /webservices/axis/trunk/java/modules: core/src/org/apache/axis/clientapi/ core/src/org/apache/axis/context/ core/src/org/apache/axis/deployment/ core/src/org/apache/axis/deployment/repository/utill/ core/src/org/apache/axis/description/ core/src/org/apache/axis/engine/ core/src/org/apache/axis/handlers/ core/src/org/apache/axis/modules/ core/src/org/apache/axis/phaseresolver/ core/src/org/apache/axis/receivers/ core/src/org/apache/axis/transport/ core/src/org/apache/axis/transport/http/ core/src/org/apache/axis/transport/mail/ core/src/org/apache/axis/util/ core/test/org/apache/axis/context/ core/test/org/apache/axis/deployment/ core/test/org/apache/axis/description/ core/test/org/apache/axis/engine/ core/test/org/apache/axis/phaserule/ samples/src/encoding/sample1/ samples/src/encoding/sample2/benchMark/ samples/src/interop/doclit/ samples/src/org/apache/axis/testUtils/ samples/test/org/apache/axis/clientapi/ samples/test/org/apache/axis/engine/ samples/test/org/apache/axis/integration/ wsdl/src/org/apache/axis/wsdl/codegen/emitter/

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseHolder.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseHolder.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseHolder.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseHolder.java Thu May 12 05:32:55 2005
@@ -17,11 +17,11 @@
 
 import java.util.ArrayList;
 
-import org.apache.axis.context.SystemContext;
-import org.apache.axis.description.HandlerMetadata;
+import org.apache.axis.context.ConfigurationContext;
+import org.apache.axis.description.HandlerDescription;
 import org.apache.axis.description.PhasesInclude;
 import org.apache.axis.engine.AxisFault;
-import org.apache.axis.engine.AxisSystem;
+import org.apache.axis.engine.AxisConfiguration;
 import org.apache.axis.engine.Handler;
 import org.apache.axis.engine.Phase;
 
@@ -39,7 +39,7 @@
     /**
      * Referance to ServerMetaData inorder to get information about phases.
      */
-    private final AxisSystem registry;    // = new  ServerMetaData();
+    private final AxisConfiguration registry;    // = new  ServerMetaData();
 
     private PhasesInclude phaseInclude;
 
@@ -54,13 +54,13 @@
      *
      * @param registry
      */
-    public PhaseHolder(AxisSystem registry, PhasesInclude phaseInclude) {
+    public PhaseHolder(AxisConfiguration registry, PhasesInclude phaseInclude) {
         this.registry = registry;
         this.phaseInclude = phaseInclude;
         fillFlowPhases();
     }
 
-    public PhaseHolder(AxisSystem registry) {
+    public PhaseHolder(AxisConfiguration registry) {
         this.registry = registry;
         this.phaseInclude = null;
         fillFlowPhases();
@@ -151,7 +151,7 @@
      * @param handler
      * @throws PhaseException
      */
-    public void addHandler(HandlerMetadata handler) throws PhaseException {
+    public void addHandler(HandlerDescription handler) throws PhaseException {
         String phaseName = handler.getRules().getPhaseName();
         if (isPhaseExist(phaseName)) {
             getPhase(phaseName).addHandler(handler);
@@ -195,7 +195,7 @@
     public ArrayList getOrderHandler() throws PhaseException {
         ArrayList handlerList = new ArrayList();
         //OrderThePhases();
-        HandlerMetadata[] handlers;
+        HandlerDescription[] handlers;
         for (int i = 0; i < phaseholder.size(); i++) {
             PhaseMetadata phase =
                     (PhaseMetadata) phaseholder.get(i);
@@ -224,7 +224,7 @@
         try {
             //OrderThePhases();
 
-            HandlerMetadata[] handlers;
+            HandlerDescription[] handlers;
             switch (chainType) {
                 case PhaseMetadata.IN_FLOW:
                     {
@@ -239,7 +239,7 @@
                             }
                             inChain.add(axisPhase);
                         }
-                        phaseInclude.setPhases(inChain, AxisSystem.INFLOW);
+                        phaseInclude.setPhases(inChain, AxisConfiguration.INFLOW);
                         // service.setPhases(inChain, EngineConfiguration.INFLOW);
                         break;
                     }
@@ -257,7 +257,7 @@
                             outChain.add(axisPhase);
                         }
                         //service.setPhases(outChain, EngineConfiguration.OUTFLOW);
-                        phaseInclude.setPhases(outChain, AxisSystem.OUTFLOW);
+                        phaseInclude.setPhases(outChain, AxisConfiguration.OUTFLOW);
                         break;
                     }
                 case PhaseMetadata.FAULT_IN_FLOW:
@@ -273,7 +273,7 @@
                             }
                             faultInChain.add(axisPhase);
                         }
-                        phaseInclude.setPhases(faultInChain, AxisSystem.FAULT_IN_FLOW);
+                        phaseInclude.setPhases(faultInChain, AxisConfiguration.FAULT_IN_FLOW);
                         // service.setPhases(faultInChain, EngineConfiguration.FAULT_IN_FLOW);
                         break;
                     }
@@ -290,7 +290,7 @@
                             }
                             faultOutChain.add(axisPhase);
                         }
-                        phaseInclude.setPhases(faultOutChain, AxisSystem.FAULT_OUT_FLOW);
+                        phaseInclude.setPhases(faultOutChain, AxisConfiguration.FAULT_OUT_FLOW);
                         //   service.setPhases(faultOutChain, EngineConfiguration.FAULT_IN_FLOW);
                         break;
                     }
@@ -306,7 +306,7 @@
         try {
             //OrderThePhases();
 
-            HandlerMetadata[] handlers;
+            HandlerDescription[] handlers;
             Class handlerClass = null;
             Handler handler;
             switch (chainType) {
@@ -337,7 +337,7 @@
                             }
                             inChain.add(axisPhase);
                         }
-                        trnsport.setPhases(inChain, AxisSystem.INFLOW);
+                        trnsport.setPhases(inChain, AxisConfiguration.INFLOW);
                         break;
                     }
                 case PhaseMetadata.OUT_FLOW:
@@ -367,7 +367,7 @@
                             }
                             outChain.add(axisPhase);
                         }
-                        trnsport.setPhases(outChain, AxisSystem.OUTFLOW);
+                        trnsport.setPhases(outChain, AxisConfiguration.OUTFLOW);
                         break;
                     }
                 case PhaseMetadata.FAULT_IN_FLOW:
@@ -397,7 +397,7 @@
                             }
                             faultChain.add(axisPhase);
                         }
-                        trnsport.setPhases(faultChain, AxisSystem.FAULT_IN_FLOW);
+                        trnsport.setPhases(faultChain, AxisConfiguration.FAULT_IN_FLOW);
                         break;
                     }
                 case PhaseMetadata.FAULT_OUT_FLOW:
@@ -427,7 +427,7 @@
                             }
                             faultChain.add(axisPhase);
                         }
-                        trnsport.setPhases(faultChain, AxisSystem.FAULT_OUT_FLOW);
+                        trnsport.setPhases(faultChain, AxisConfiguration.FAULT_OUT_FLOW);
                         break;
                     }
             }
@@ -444,11 +444,11 @@
      * @param chainType
      * @throws PhaseException
      */
-    public void buildGlobalChain(SystemContext engineContext, int chainType)
+    public void buildGlobalChain(ConfigurationContext engineContext, int chainType)
             throws PhaseException {
         try {
             //OrderThePhases();
-            HandlerMetadata[] handlers;
+            HandlerDescription[] handlers;
             switch (chainType) {
                 case PhaseMetadata.IN_FLOW:
                     {
@@ -463,7 +463,7 @@
                             }
                             inChain.add(axisPhase);
                         }
-                        engineContext.setPhases(inChain, AxisSystem.INFLOW);
+                        engineContext.setPhases(inChain, AxisConfiguration.INFLOW);
                         break;
                     }
                 case PhaseMetadata.OUT_FLOW:
@@ -479,7 +479,7 @@
                             }
                             outChain.add(axisPhase);
                         }
-                        engineContext.setPhases(outChain, AxisSystem.OUTFLOW);
+                        engineContext.setPhases(outChain, AxisConfiguration.OUTFLOW);
                         break;
                     }
                 case PhaseMetadata.FAULT_IN_FLOW:
@@ -495,7 +495,7 @@
                             }
                             faultChain.add(axisPhase);
                         }
-                        engineContext.setPhases(faultChain, AxisSystem.FAULT_IN_FLOW);
+                        engineContext.setPhases(faultChain, AxisConfiguration.FAULT_IN_FLOW);
                         break;
                     }
                 case PhaseMetadata.FAULT_OUT_FLOW:
@@ -511,7 +511,7 @@
                             }
                             faultChain.add(axisPhase);
                         }
-                        engineContext.setPhases(faultChain, AxisSystem.FAULT_OUT_FLOW);
+                        engineContext.setPhases(faultChain, AxisConfiguration.FAULT_OUT_FLOW);
                         break;
                     }
             }

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseMetadata.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseMetadata.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseMetadata.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseMetadata.java Thu May 12 05:32:55 2005
@@ -17,7 +17,7 @@
 
 import java.util.ArrayList;
 
-import org.apache.axis.description.HandlerMetadata;
+import org.apache.axis.description.HandlerDescription;
 
 /**
  * Class PhaseMetadata
@@ -58,7 +58,7 @@
     /**
      * to keet info about phase first handler
      */
-    private HandlerMetadata phaseFirst;
+    private HandlerDescription phaseFirst;
 
     /**
      * Field phasefirstset
@@ -68,7 +68,7 @@
     /**
      * to keet info about phase last handler
      */
-    private HandlerMetadata phaseLast;
+    private HandlerDescription phaseLast;
 
     /**
      * Field phaselastset
@@ -109,7 +109,7 @@
      *
      * @return
      */
-    public HandlerMetadata getPhaseFirst() {
+    public HandlerDescription getPhaseFirst() {
         return phaseFirst;
     }
 
@@ -119,7 +119,7 @@
      * @param phaseFirst
      * @throws PhaseException
      */
-    public void setPhaseFirst(HandlerMetadata phaseFirst)
+    public void setPhaseFirst(HandlerDescription phaseFirst)
             throws PhaseException {
         if (phasefirstset) {
             throw new PhaseException("PhaseFirst alredy has been set, cannot have two phaseFirst Handler for same phase "
@@ -140,7 +140,7 @@
      *
      * @return
      */
-    public HandlerMetadata getPhaseLast() {
+    public HandlerDescription getPhaseLast() {
         return phaseLast;
     }
 
@@ -150,7 +150,7 @@
      * @param phaseLast
      * @throws PhaseException
      */
-    public void setPhaseLast(HandlerMetadata phaseLast) throws PhaseException {
+    public void setPhaseLast(HandlerDescription phaseLast) throws PhaseException {
         if (phaselastset) {
             throw new PhaseException("PhaseLast already has been set, cannot have two PhaseLast Handler for same phase "
                     + this.name);
@@ -171,7 +171,7 @@
      * @param handler
      * @throws PhaseException
      */
-    public void addHandler(HandlerMetadata handler) throws PhaseException {
+    public void addHandler(HandlerDescription handler) throws PhaseException {
         if (isonehanlder) {
             throw new PhaseException(this.getName() + "can only have one handler, since there is a " +
                     "handler with both phaseFirst and PhaseLast true ");
@@ -212,17 +212,17 @@
      * @return
      * @throws PhaseException
      */
-    public HandlerMetadata[] getOrderedHandlers() throws PhaseException {
+    public HandlerDescription[] getOrderedHandlers() throws PhaseException {
         int size = 0;
 
         /**
          * order the handlers
          */
         orderHandlers();
-        HandlerMetadata handler[];
+        HandlerDescription handler[];
         if (isonehanlder) {
             size = 1;
-            handler = new HandlerMetadata[size];
+            handler = new HandlerDescription[size];
             handler[0] = getPhaseFirst();
             return handler;
         }
@@ -237,9 +237,9 @@
             phaseHandlers.add(getPhaseLast());
         }
         size = phaseHandlers.size();
-        handler = new HandlerMetadata[size];
+        handler = new HandlerDescription[size];
         for (int i = 0; i < phaseHandlers.size(); i++) {
-            handler[i] = (HandlerMetadata) phaseHandlers.get(i);
+            handler[i] = (HandlerDescription) phaseHandlers.get(i);
         }
         return handler;
     }
@@ -268,8 +268,8 @@
         if (getPhaseFirst() != null) {
             String phasFirstname = getPhaseFirst().getName().getLocalPart();
             for (int i = 0; i < phaseHandlers.size(); i++) {
-                HandlerMetadata handler =
-                        (HandlerMetadata) phaseHandlers.get(i);
+                HandlerDescription handler =
+                        (HandlerDescription) phaseHandlers.get(i);
                 if (handler.getRules().getBefore().equals(phasFirstname)) {
                     throw new PhaseException("Try to insert  a Handler "
                             + handler.getName()
@@ -292,8 +292,8 @@
         if (getPhaseLast() != null) {
             String phaseLastName = getPhaseLast().getName().getLocalPart();
             for (int i = 0; i < phaseHandlers.size(); i++) {
-                HandlerMetadata handler =
-                        (HandlerMetadata) phaseHandlers.get(i);
+                HandlerDescription handler =
+                        (HandlerDescription) phaseHandlers.get(i);
                 if (handler.getName().equals(phaseLastName)) {
                     throw new PhaseException("Try to insert a Handler "
                             + handler.getName()
@@ -313,12 +313,12 @@
         int count = 0;
         int before_after = 0;
         boolean status = false;
-        HandlerMetadata handler = null;
+        HandlerDescription handler = null;
         while (phaseHandlers.size() > 0) {
             if (status) {
-                handler = (HandlerMetadata) phaseHandlers.get(0);
+                handler = (HandlerDescription) phaseHandlers.get(0);
             } else {
-                handler = (HandlerMetadata) phaseHandlers.get(count);
+                handler = (HandlerDescription) phaseHandlers.get(count);
             }
             status = false;
             if (count > phaseHandlers.size()) {
@@ -375,7 +375,7 @@
      * @return
      * @throws PhaseException
      */
-    private int getBeforeAfter(HandlerMetadata handler) throws PhaseException {
+    private int getBeforeAfter(HandlerDescription handler) throws PhaseException {
         if ((!handler.getRules().getBefore().equals(""))
                 && (!handler.getRules().getAfter().equals(""))) {
             if (handler.getRules().getBefore().equals(handler.getRules().getAfter())) {
@@ -398,7 +398,7 @@
      * @param handler
      * @return
      */
-    private boolean insertBefore(HandlerMetadata handler) {
+    private boolean insertBefore(HandlerDescription handler) {
         String beforename = handler.getRules().getBefore();
         if (getPhaseLast() != null) {
             if (getPhaseLast().getName().getLocalPart().equals(beforename)) {
@@ -407,7 +407,7 @@
             }
         }
         for (int i = 0; i < orderHanders.size(); i++) {
-            HandlerMetadata temphandler = (HandlerMetadata) orderHanders.get(i);
+            HandlerDescription temphandler = (HandlerDescription) orderHanders.get(i);
             if (temphandler.getName().getLocalPart().equals(beforename)) {
                 orderHanders.add(i, handler);
                 return true;
@@ -422,7 +422,7 @@
      * @param handler
      * @return
      */
-    private boolean insertAfter(HandlerMetadata handler) {
+    private boolean insertAfter(HandlerDescription handler) {
         String afterName = handler.getRules().getAfter();
         if (getPhaseFirst() != null) {
             if (getPhaseFirst().getName().getLocalPart().equals(afterName)) {
@@ -431,7 +431,7 @@
             }
         }
         for (int i = 0; i < orderHanders.size(); i++) {
-            HandlerMetadata temphandler = (HandlerMetadata) orderHanders.get(i);
+            HandlerDescription temphandler = (HandlerDescription) orderHanders.get(i);
             if (temphandler.getName().getLocalPart().equals(afterName)) {
                 if (i == orderHanders.size() - 1) {
                     orderHanders.add(handler);
@@ -453,7 +453,7 @@
      * @return
      * @throws PhaseException
      */
-    private boolean insertBeforeandAfter(HandlerMetadata handler)
+    private boolean insertBeforeandAfter(HandlerDescription handler)
             throws PhaseException {
         int before = -1;
         int after = -1;
@@ -480,7 +480,7 @@
         }
 
         for (int i = 0; i < orderHanders.size(); i++) {
-            HandlerMetadata temphandler = (HandlerMetadata) orderHanders.get(i);
+            HandlerDescription temphandler = (HandlerDescription) orderHanders.get(i);
             if (handler.getRules().getAfter().equals(temphandler.getName().getLocalPart())) {
                 after = i;
             } else if (handler.getRules().getBefore().equals(temphandler.getName().getLocalPart())) {

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseResolver.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseResolver.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/receivers/AbstractMessageReceiver.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/receivers/AbstractMessageReceiver.java Thu May 12 05:32:55 2005
@@ -21,7 +21,7 @@
 import org.apache.axis.Constants;
 import org.apache.axis.context.MessageContext;
 import org.apache.axis.context.SessionContext;
-import org.apache.axis.description.AxisService;
+import org.apache.axis.description.ServiceDescription;
 import org.apache.axis.description.Parameter;
 import org.apache.axis.engine.AxisFault;
 import org.apache.axis.engine.MessageReceiver;
@@ -39,7 +39,7 @@
      */
     protected Object makeNewServiceObject(MessageContext msgContext) throws AxisFault {
         try {
-            AxisService service =
+            ServiceDescription service =
                 msgContext.getOperationContext().getServiceContext().getServiceConfig();
             ClassLoader classLoader = service.getClassLoader();
             Parameter implInfoParam = service.getParameter(SERVICE_CLASS);
@@ -64,7 +64,7 @@
       * @throws AxisFault
       */
     protected Object getTheImplementationObject(MessageContext msgContext) throws AxisFault {
-        AxisService service =
+        ServiceDescription service =
             msgContext.getOperationContext().getServiceContext().getServiceConfig();
 
         Parameter scopeParam = service.getParameter(SCOPE);

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/receivers/RawXMLINOutMessageRecevier.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/receivers/RawXMLINOutMessageRecevier.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/receivers/RawXMLINOutMessageRecevier.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/receivers/RawXMLINOutMessageRecevier.java Thu May 12 05:32:55 2005
@@ -72,7 +72,7 @@
 ////            // find the WebService method
 ////            Class ImplClass = obj.getClass();
 ////
-////            AxisOperation op = msgContext.getOperationContext().getAxisOperation();
+////            OperationDescription op = msgContext.getOperationContext().getAxisOperation();
 ////            if (op == null) {
 ////                throw new AxisFault("Operation is not located, if this is doclit style the SOAP-ACTION should specified via the SOAP Action to use the RawXMLProvider");
 ////            }

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/AbstractTransportSender.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/AbstractTransportSender.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/AbstractTransportSender.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/AbstractTransportSender.java Thu May 12 05:32:55 2005
@@ -24,7 +24,7 @@
 import org.apache.axis.addressing.AddressingConstants;
 import org.apache.axis.addressing.EndpointReference;
 import org.apache.axis.context.MessageContext;
-import org.apache.axis.description.HandlerMetadata;
+import org.apache.axis.description.HandlerDescription;
 import org.apache.axis.engine.AxisFault;
 import org.apache.axis.handlers.AbstractHandler;
 import org.apache.axis.om.SOAPEnvelope;
@@ -48,7 +48,7 @@
      * Constructor AbstractTransportSender
      */
     public AbstractTransportSender() {
-        init(new HandlerMetadata(NAME));
+        init(new HandlerDescription(NAME));
     }
 
     /**

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/TransportReceiver.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/TransportReceiver.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/TransportReceiver.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/TransportReceiver.java Thu May 12 05:32:55 2005
@@ -17,12 +17,12 @@
 
 
 import org.apache.axis.context.MessageContext;
-import org.apache.axis.context.SystemContext;
+import org.apache.axis.context.ConfigurationContext;
 import org.apache.axis.engine.AxisFault;
 
 /**
  * Class TransportReceiver
  */
 public abstract class TransportReceiver{
-    public abstract void invoke(MessageContext msgContext,SystemContext engineContext) throws AxisFault;
+    public abstract void invoke(MessageContext msgContext,ConfigurationContext engineContext) throws AxisFault;
 }

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/http/AxisServlet.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/http/AxisServlet.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/http/AxisServlet.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/http/AxisServlet.java Thu May 12 05:32:55 2005
@@ -39,7 +39,7 @@
 import org.apache.axis.context.EngineContextFactory;
 import org.apache.axis.context.MessageContext;
 import org.apache.axis.context.SessionContext;
-import org.apache.axis.context.SystemContext;
+import org.apache.axis.context.ConfigurationContext;
 import org.apache.axis.engine.AxisEngine;
 import org.apache.axis.engine.AxisFault;
 import org.apache.axis.om.SOAPEnvelope;
@@ -54,7 +54,7 @@
      * Field engineRegistry
      */
     
-    private SystemContext engineContext;
+    private ConfigurationContext engineContext;
 
     /**
      * Field LIST_MULTIPLE_SERVICE_JSP_NAME

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/http/HTTPTransportReceiver.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/http/HTTPTransportReceiver.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/http/HTTPTransportReceiver.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/http/HTTPTransportReceiver.java Thu May 12 05:32:55 2005
@@ -26,7 +26,7 @@
 import org.apache.axis.addressing.AddressingConstants;
 import org.apache.axis.addressing.EndpointReference;
 import org.apache.axis.context.MessageContext;
-import org.apache.axis.context.SystemContext;
+import org.apache.axis.context.ConfigurationContext;
 import org.apache.axis.engine.AxisEngine;
 import org.apache.axis.engine.AxisFault;
 import org.apache.axis.om.SOAPEnvelope;
@@ -89,7 +89,7 @@
      * @param msgContext
      * @throws AxisFault
      */
-    public void invoke(MessageContext msgContext,SystemContext engineContext) throws AxisFault{
+    public void invoke(MessageContext msgContext,ConfigurationContext engineContext) throws AxisFault{
         Reader in = (Reader) msgContext.getProperty(MessageContext.TRANSPORT_READER);
         if (in != null) {
             boolean serverSide = msgContext.isServerSide();

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/http/SimpleHTTPServer.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/http/SimpleHTTPServer.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/http/SimpleHTTPServer.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/http/SimpleHTTPServer.java Thu May 12 05:32:55 2005
@@ -29,8 +29,8 @@
 import org.apache.axis.addressing.AddressingConstants;
 import org.apache.axis.context.EngineContextFactory;
 import org.apache.axis.context.MessageContext;
-import org.apache.axis.context.SystemContext;
-import org.apache.axis.description.AxisTransportOut;
+import org.apache.axis.context.ConfigurationContext;
+import org.apache.axis.description.TransportOutDescription;
 import org.apache.axis.engine.AxisFault;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -53,7 +53,7 @@
     /**
      * Field systemContext
      */
-    protected SystemContext systemContext;
+    protected ConfigurationContext systemContext;
 
     /**
      * Field serverSocket
@@ -76,7 +76,7 @@
      *
      * @param systemContext
      */
-    public SimpleHTTPServer(SystemContext systemContext, ServerSocket serverSoc) {
+    public SimpleHTTPServer(ConfigurationContext systemContext, ServerSocket serverSoc) {
         this.systemContext = systemContext;
         this.serverSocket = serverSoc;
     }
@@ -132,7 +132,7 @@
                         }
                         Writer out = new OutputStreamWriter(socket.getOutputStream());
                         Reader in = new InputStreamReader(socket.getInputStream());
-                        AxisTransportOut transportOut =
+                        TransportOutDescription transportOut =
                             systemContext.getEngineConfig().getTransportOut(
                                 new QName(Constants.TRANSPORT_HTTP));
                         MessageContext msgContext =
@@ -251,7 +251,7 @@
      *
      * @return
      */
-    public SystemContext getSystemContext() {
+    public ConfigurationContext getSystemContext() {
         return systemContext;
     }
 

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/mail/MailWorker.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/mail/MailWorker.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/mail/MailWorker.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/mail/MailWorker.java Thu May 12 05:32:55 2005
@@ -32,7 +32,7 @@
 import org.apache.axis.addressing.AddressingConstants;
 import org.apache.axis.addressing.EndpointReference;
 import org.apache.axis.context.MessageContext;
-import org.apache.axis.context.SystemContext;
+import org.apache.axis.context.ConfigurationContext;
 import org.apache.axis.engine.AxisEngine;
 import org.apache.axis.engine.AxisFault;
 import org.apache.axis.om.SOAPEnvelope;
@@ -53,7 +53,7 @@
 
     private SMTPClient client = null;
 
-    private SystemContext reg = null;
+    private ConfigurationContext reg = null;
 
     // Current message
     private MimeMessage mimeMessage;
@@ -75,7 +75,7 @@
      * @param mimeMessage
      */
     public MailWorker(SimpleMailListner server, MimeMessage mimeMessage,
-                      SystemContext reg) {
+                      ConfigurationContext reg) {
         this.server = server;
         this.mimeMessage = mimeMessage;
         this.reg = reg;

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/mail/SimpleMailListner.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/mail/SimpleMailListner.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/mail/SimpleMailListner.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/mail/SimpleMailListner.java Thu May 12 05:32:55 2005
@@ -25,9 +25,9 @@
 import javax.mail.internet.MimeMessage;
 
 import org.apache.axis.context.EngineContextFactory;
-import org.apache.axis.context.SystemContext;
+import org.apache.axis.context.ConfigurationContext;
 import org.apache.axis.engine.AxisEngine;
-import org.apache.axis.engine.AxisSystem;
+import org.apache.axis.engine.AxisConfiguration;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.commons.net.pop3.POP3Client;
@@ -65,7 +65,7 @@
 
     private String password;
 
-    private static SystemContext er = null;
+    private static ConfigurationContext er = null;
 
     public SimpleMailListner(String host, int port, String userid, String password,
             String dir) {
@@ -109,7 +109,7 @@
 
     //This is needed to create the AxisEngine. Have to find out how to get this
     // wrking in the class -- CT 07-Feb-2005.
-    private static AxisSystem reg = null;
+    private static AxisConfiguration reg = null;
 
     protected static synchronized AxisEngine getAxisEngine() {
         if (myAxisEngine == null) {

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/util/Utils.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/util/Utils.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/util/Utils.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/util/Utils.java Thu May 12 05:32:55 2005
@@ -19,14 +19,14 @@
 
 import org.apache.axis.Constants;
 import org.apache.axis.context.ServiceContext;
-import org.apache.axis.context.SystemContext;
-import org.apache.axis.description.AxisOperation;
-import org.apache.axis.description.AxisService;
+import org.apache.axis.context.ConfigurationContext;
+import org.apache.axis.description.OperationDescription;
+import org.apache.axis.description.ServiceDescription;
 import org.apache.axis.description.Flow;
-import org.apache.axis.description.HandlerMetadata;
+import org.apache.axis.description.HandlerDescription;
 import org.apache.axis.description.ParameterImpl;
 import org.apache.axis.engine.AxisFault;
-import org.apache.axis.engine.AxisSystem;
+import org.apache.axis.engine.AxisConfiguration;
 import org.apache.axis.engine.Handler;
 import org.apache.axis.engine.MessageReceiver;
 import org.apache.axis.engine.Phase;
@@ -36,7 +36,7 @@
 public class Utils {
 
     public static void addHandler(Flow flow, Handler handler) {
-        HandlerMetadata hmd = new HandlerMetadata();
+        HandlerDescription hmd = new HandlerDescription();
         hmd.setHandler(handler);
         flow.addHandler(hmd);
     }
@@ -56,48 +56,48 @@
     }
 
     public static void createExecutionChains(ServiceContext serviceContext) throws AxisFault {
-        AxisService service = serviceContext.getServiceConfig();
+        ServiceDescription service = serviceContext.getServiceConfig();
         addPhasesToServiceFromFlow(
             serviceContext,
             Constants.PHASE_SERVICE,
             service.getInFlow(),
-            AxisSystem.INFLOW);
+            AxisConfiguration.INFLOW);
         addPhasesToServiceFromFlow(
             serviceContext,
             Constants.PHASE_SERVICE,
             service.getOutFlow(),
-            AxisSystem.OUTFLOW);
+            AxisConfiguration.OUTFLOW);
         addPhasesToServiceFromFlow(
             serviceContext,
             Constants.PHASE_SERVICE,
             service.getFaultInFlow(),
-            AxisSystem.FAULT_IN_FLOW);
+            AxisConfiguration.FAULT_IN_FLOW);
     }
 
-    public static AxisService createSimpleService(
+    public static ServiceDescription createSimpleService(
         QName serviceName,
         MessageReceiver messageReceiver,
         String className,
         QName opName) {
-        AxisService service = new AxisService(serviceName);
+        ServiceDescription service = new ServiceDescription(serviceName);
         service.setClassLoader(Thread.currentThread().getContextClassLoader());
         service.addParameter(new ParameterImpl(AbstractMessageReceiver.SERVICE_CLASS, className));
-        AxisOperation axisOp = new AxisOperation(opName);
+        OperationDescription axisOp = new OperationDescription(opName);
         axisOp.setMessageReciever(messageReceiver);
         service.addOperation(axisOp);
         return service;
     }
 
     public static ServiceContext createServiceContext(
-        AxisService service,
-        SystemContext engineContext)
+        ServiceDescription service,
+        ConfigurationContext engineContext)
         throws AxisFault {
         ServiceContext serviceContext = new ServiceContext(service, engineContext);
         createExecutionChains(serviceContext);
         return serviceContext;
     }
 
-    public static AxisService createSimpleService(
+    public static ServiceDescription createSimpleService(
         QName serviceName,
         String className,
         QName opName) {

Modified: webservices/axis/trunk/java/modules/core/test/org/apache/axis/context/MEPContextTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test/org/apache/axis/context/MEPContextTest.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test/org/apache/axis/context/MEPContextTest.java (original)
+++ webservices/axis/trunk/java/modules/core/test/org/apache/axis/context/MEPContextTest.java Thu May 12 05:32:55 2005
@@ -20,10 +20,10 @@
 
 import org.apache.axis.AbstractTestCase;
 import org.apache.axis.addressing.miheaders.RelatesTo;
-import org.apache.axis.description.AxisOperation;
-import org.apache.axis.description.AxisService;
-import org.apache.axis.description.AxisTransportIn;
-import org.apache.axis.description.AxisTransportOut;
+import org.apache.axis.description.OperationDescription;
+import org.apache.axis.description.ServiceDescription;
+import org.apache.axis.description.TransportInDescription;
+import org.apache.axis.description.TransportOutDescription;
 import org.apache.axis.engine.AxisFault;
 
 /**
@@ -32,7 +32,7 @@
  */
 public class MEPContextTest extends AbstractTestCase {
 
-	private SystemContext engineCtx = new SystemContext(null);
+	private ConfigurationContext engineCtx = new ConfigurationContext(null);
 
     public MEPContextTest(String arg0) {
         super(arg0);
@@ -40,11 +40,11 @@
     //FIXME TODO Chathura
     public void testMEPfindingOnRelatesTO() throws Exception{
     	 
-    	ServiceContext sessionContext = new ServiceContext(new AxisService(),new SystemContext(null));
+    	ServiceContext sessionContext = new ServiceContext(new ServiceDescription(),new ConfigurationContext(null));
 		MessageContext messageContext1 = this.getBasicMessageContext();
     	
     	messageContext1.setMessageID(new Long(System.currentTimeMillis()).toString());
-    	AxisOperation axisOperation = new AxisOperation(new QName("test"));
+    	OperationDescription axisOperation = new OperationDescription(new QName("test"));
     	OperationContext operationContext1 = axisOperation.findOperationContext(messageContext1, sessionContext, true);
     	
     	MessageContext messageContext2 = this.getBasicMessageContext();
@@ -56,7 +56,7 @@
     
     public MessageContext getBasicMessageContext() throws AxisFault{
 
-    	return new MessageContext(null,new AxisTransportIn(new QName("axis")), new AxisTransportOut(new QName("axis")),engineCtx);
+    	return new MessageContext(null,new TransportInDescription(new QName("axis")), new TransportOutDescription(new QName("axis")),engineCtx);
 
     }
     

Modified: webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadModuleTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadModuleTest.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadModuleTest.java (original)
+++ webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadModuleTest.java Thu May 12 05:32:55 2005
@@ -21,7 +21,7 @@
 import java.io.InputStream;
 
 import org.apache.axis.AbstractTestCase;
-import org.apache.axis.description.AxisGlobal;
+import org.apache.axis.description.GlobalDescription;
 
 public class BadModuleTest extends AbstractTestCase {
     /**
@@ -35,7 +35,7 @@
         try {
             InputStream in = new FileInputStream(getTestResourceFile("deployment/Badmodule.xml"));
             DeploymentParser parser = new DeploymentParser(in, null);
-            AxisGlobal glabl = new AxisGlobal();
+            GlobalDescription glabl = new GlobalDescription();
             parser.processGlobalConfig(glabl);
             fail("this must failed gracefully with DeploymentException or FileNotFoundException");
         } catch (FileNotFoundException e) {

Modified: webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadServerXMLTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadServerXMLTest.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadServerXMLTest.java (original)
+++ webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadServerXMLTest.java Thu May 12 05:32:55 2005
@@ -21,7 +21,7 @@
 import java.io.InputStream;
 
 import org.apache.axis.AbstractTestCase;
-import org.apache.axis.description.AxisGlobal;
+import org.apache.axis.description.GlobalDescription;
 
 public class BadServerXMLTest extends AbstractTestCase {
     /**
@@ -35,7 +35,7 @@
         try {
             InputStream in = new FileInputStream(getTestResourceFile("deployment/BadServer.xml"));
             DeploymentParser parser = new DeploymentParser(in, null);
-            AxisGlobal glabl = new AxisGlobal();
+            GlobalDescription glabl = new GlobalDescription();
             parser.processGlobalConfig(glabl);
             fail("this must failed gracefully with DeploymentException or FileNotFoundException");
         } catch (FileNotFoundException e) {

Modified: webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadServiceXMLTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadServiceXMLTest.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadServiceXMLTest.java (original)
+++ webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadServiceXMLTest.java Thu May 12 05:32:55 2005
@@ -21,7 +21,7 @@
 import java.io.InputStream;
 
 import org.apache.axis.AbstractTestCase;
-import org.apache.axis.description.AxisService;
+import org.apache.axis.description.ServiceDescription;
 
 public class BadServiceXMLTest extends AbstractTestCase {
     /**
@@ -35,7 +35,7 @@
         try {
             InputStream in = new FileInputStream(getTestResourceFile("deployment/BadService.xml"));
             DeploymentParser parser = new DeploymentParser(in, null);
-            AxisService axisService = new AxisService();
+            ServiceDescription axisService = new ServiceDescription();
             parser.parseServiceXML(axisService);
             fail("this must failed gracefully with DeploymentException or FileNotFoundException");
         } catch (FileNotFoundException e) {

Modified: webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BuildERWithDeploymentTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BuildERWithDeploymentTest.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BuildERWithDeploymentTest.java (original)
+++ webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BuildERWithDeploymentTest.java Thu May 12 05:32:55 2005
@@ -20,10 +20,10 @@
 
 import org.apache.axis.AbstractTestCase;
 import org.apache.axis.context.EngineContextFactory;
-import org.apache.axis.description.AxisOperation;
-import org.apache.axis.description.AxisService;
+import org.apache.axis.description.OperationDescription;
+import org.apache.axis.description.ServiceDescription;
 import org.apache.axis.description.Flow;
-import org.apache.axis.engine.AxisSystem;
+import org.apache.axis.engine.AxisConfiguration;
 
 public class BuildERWithDeploymentTest extends AbstractTestCase {
     /**
@@ -36,11 +36,11 @@
     public void testDeployment() throws Exception {
         String filename = "./target/test-resources/deployment";
         EngineContextFactory builder = new EngineContextFactory();
-        AxisSystem er = builder.buildEngineContext(filename).getEngineConfig();
+        AxisConfiguration er = builder.buildEngineContext(filename).getEngineConfig();
 
         assertNotNull(er);
         assertNotNull(er.getGlobal());
-        AxisService service = er.getService(new QName("service2"));
+        ServiceDescription service = er.getService(new QName("service2"));
         assertNotNull(service);
         //commentd since there is no service based messgeRecivers
         /*MessageReceiver provider = service.getMessageReceiver();
@@ -61,7 +61,7 @@
         assertTrue( flow.getHandlerCount() > 0);
         assertNotNull(service.getParameter("para2"));
 
-        AxisOperation op = service.getOperation(new QName("opname"));
+        OperationDescription op = service.getOperation(new QName("opname"));
         assertNotNull(op);
 
     }

Modified: webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BuildWithAddressingTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BuildWithAddressingTest.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BuildWithAddressingTest.java (original)
+++ webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BuildWithAddressingTest.java Thu May 12 05:32:55 2005
@@ -6,9 +6,9 @@
 
 import org.apache.axis.AbstractTestCase;
 import org.apache.axis.context.EngineContextFactory;
-import org.apache.axis.context.SystemContext;
-import org.apache.axis.description.AxisModule;
-import org.apache.axis.engine.AxisSystem;
+import org.apache.axis.context.ConfigurationContext;
+import org.apache.axis.description.ModuleDescription;
+import org.apache.axis.engine.AxisConfiguration;
 import org.apache.axis.engine.Phase;
 
 /*
@@ -43,9 +43,9 @@
     public void testDeployment() throws Exception {
         String filename = "./target/test-resources/deployment";
         EngineContextFactory builder = new EngineContextFactory();
-        SystemContext er = builder.buildEngineContext(filename);
-        ArrayList phases = er.getPhases(AxisSystem.INFLOW);
-        AxisModule modeule = er.getEngineConfig().getModule(new QName("addressing"));
+        ConfigurationContext er = builder.buildEngineContext(filename);
+        ArrayList phases = er.getPhases(AxisConfiguration.INFLOW);
+        ModuleDescription modeule = er.getEngineConfig().getModule(new QName("addressing"));
         assertNotNull(modeule);
         if (phases.size() <= 0) {
             fail("this must failed Since there are addressing handlers ");

Modified: webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/DeploymentotalTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/DeploymentotalTest.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/DeploymentotalTest.java (original)
+++ webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/DeploymentotalTest.java Thu May 12 05:32:55 2005
@@ -22,11 +22,11 @@
 
 import org.apache.axis.context.EngineContextFactory;
 import org.apache.axis.engine.AxisFault;
-import org.apache.axis.engine.AxisSystem;
+import org.apache.axis.engine.AxisConfiguration;
 import org.apache.axis.phaseresolver.PhaseException;
 
 public class DeploymentotalTest extends TestCase {
-    AxisSystem er;
+    AxisConfiguration er;
 
     public void testparseService1() throws PhaseException, DeploymentException, AxisFault, XMLStreamException {
         String filename = "./target/test-resources/deployment";

Modified: webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/TransportDeploymentTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/TransportDeploymentTest.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/TransportDeploymentTest.java (original)
+++ webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/TransportDeploymentTest.java Thu May 12 05:32:55 2005
@@ -20,10 +20,10 @@
 import javax.xml.stream.XMLStreamException;
 
 import org.apache.axis.AbstractTestCase;
-import org.apache.axis.description.AxisTransportIn;
-import org.apache.axis.description.AxisTransportOut;
+import org.apache.axis.description.TransportInDescription;
+import org.apache.axis.description.TransportOutDescription;
 import org.apache.axis.engine.AxisFault;
-import org.apache.axis.engine.AxisSystem;
+import org.apache.axis.engine.AxisConfiguration;
 import org.apache.axis.phaseresolver.PhaseException;
 
 public class TransportDeploymentTest extends AbstractTestCase {
@@ -37,11 +37,11 @@
     public void testTransports() throws AxisFault, PhaseException, DeploymentException, XMLStreamException {
         DeploymentEngine engine = new DeploymentEngine(testResourceDir + "/deployment", "server-transport.xml");
         engine.load();
-        AxisSystem er = engine.getEngineconfig();
-        AxisTransportIn transport = er.getTransportIn(new QName("http"));
+        AxisConfiguration er = engine.getEngineconfig();
+        TransportInDescription transport = er.getTransportIn(new QName("http"));
         assertNotNull(transport);
         assertNotNull(transport.getInFlow());
-        AxisTransportOut transport1 = er.getTransportOut(new QName("http"));
+        TransportOutDescription transport1 = er.getTransportOut(new QName("http"));
         assertNotNull(transport1);
         assertNotNull(transport1.getOutFlow());
     }

Modified: webservices/axis/trunk/java/modules/core/test/org/apache/axis/description/RegistryTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test/org/apache/axis/description/RegistryTest.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test/org/apache/axis/description/RegistryTest.java (original)
+++ webservices/axis/trunk/java/modules/core/test/org/apache/axis/description/RegistryTest.java Thu May 12 05:32:55 2005
@@ -21,13 +21,13 @@
 import org.apache.axis.AbstractTestCase;
 import org.apache.axis.context.MessageContext;
 import org.apache.axis.engine.AxisFault;
-import org.apache.axis.engine.AxisSystem;
+import org.apache.axis.engine.AxisConfiguration;
 import org.apache.axis.engine.AxisSystemImpl;
 import org.apache.axis.engine.Handler;
 import org.apache.axis.handlers.AbstractHandler;
 
 public class RegistryTest extends AbstractTestCase {
-    private AxisSystem reg;
+    private AxisConfiguration reg;
 
     public RegistryTest(String testName) {
         super(testName);
@@ -35,16 +35,16 @@
 
 
     public void testRegistry() throws Exception {
-        AxisGlobal ag = new AxisGlobal();
+        GlobalDescription ag = new GlobalDescription();
         testParameteInClude(ag);
         reg = new AxisSystemImpl(ag);
 
         QName moduleName = new QName("module1");
-        AxisModule modlue = new AxisModule(moduleName);
+        ModuleDescription modlue = new ModuleDescription(moduleName);
         reg.addMdoule(modlue);
 
         QName serviceName = new QName("service");
-        AxisService service = new AxisService(serviceName);
+        ServiceDescription service = new ServiceDescription(serviceName);
         reg.addService(service);
 
         assertSame(modlue, reg.getModule(moduleName));
@@ -56,12 +56,12 @@
     }
 
     public void testHandlerMedatata() {
-        HandlerMetadata hmd = new HandlerMetadata();
+        HandlerDescription hmd = new HandlerDescription();
         testParameteInClude(hmd);
     }
 
     public void testService() {
-        AxisService service = new AxisService(new QName("Service1"));
+        ServiceDescription service = new ServiceDescription(new QName("Service1"));
         testParameteInClude(service);
         testFlowIncludeTest(service);
 
@@ -69,13 +69,13 @@
     }
 
     public void testModule() {
-        AxisModule module = new AxisModule(new QName("module1"));
+        ModuleDescription module = new ModuleDescription(new QName("module1"));
         testParameteInClude(module);
         testFlowIncludeTest(module);
     }
 
     public void testOpeartion() {
-        AxisOperation op = new AxisOperation(new QName("op"));
+        OperationDescription op = new OperationDescription(new QName("op"));
         testParameteInClude(op);
     }
 
@@ -107,7 +107,7 @@
             public void invoke(MessageContext msgContext) throws AxisFault {
             }
         };
-        handler.init(new HandlerMetadata());
+        handler.init(new HandlerDescription());
         assertNull(handler.getName());
         assertNull(handler.getParameter("hello"));
         handler.cleanup();

Modified: webservices/axis/trunk/java/modules/core/test/org/apache/axis/engine/AbstractEngineTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test/org/apache/axis/engine/AbstractEngineTest.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test/org/apache/axis/engine/AbstractEngineTest.java (original)
+++ webservices/axis/trunk/java/modules/core/test/org/apache/axis/engine/AbstractEngineTest.java Thu May 12 05:32:55 2005
@@ -23,8 +23,8 @@
 import junit.framework.TestCase;
 
 import org.apache.axis.context.MessageContext;
-import org.apache.axis.description.AxisService;
-import org.apache.axis.description.HandlerMetadata;
+import org.apache.axis.description.ServiceDescription;
+import org.apache.axis.description.HandlerDescription;
 import org.apache.axis.description.Parameter;
 import org.apache.axis.receivers.AbstractInOutSyncMessageReceiver;
 import org.apache.axis.transport.TransportSender;
@@ -32,10 +32,10 @@
 public class AbstractEngineTest extends TestCase {
     protected MessageContext mc;
     protected ArrayList executedHandlers = new ArrayList();
-    protected AxisSystem engineRegistry;
+    protected AxisConfiguration engineRegistry;
     protected QName serviceName = new QName("axis/services/NullService");
     protected QName opearationName = new QName("NullOperation");
-    protected AxisService service;
+    protected ServiceDescription service;
 
     public AbstractEngineTest() {
     }
@@ -85,7 +85,7 @@
             return null;
         }
 
-        public void init(HandlerMetadata handlerdesc) {
+        public void init(HandlerDescription handlerdesc) {
         }
 
         public void invoke(MessageContext msgContext) throws AxisFault {

Modified: webservices/axis/trunk/java/modules/core/test/org/apache/axis/engine/EnginePausingTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test/org/apache/axis/engine/EnginePausingTest.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test/org/apache/axis/engine/EnginePausingTest.java (original)
+++ webservices/axis/trunk/java/modules/core/test/org/apache/axis/engine/EnginePausingTest.java Thu May 12 05:32:55 2005
@@ -23,12 +23,12 @@
 import org.apache.axis.context.MessageContext;
 import org.apache.axis.context.OperationContextFactory;
 import org.apache.axis.context.ServiceContext;
-import org.apache.axis.context.SystemContext;
-import org.apache.axis.description.AxisGlobal;
-import org.apache.axis.description.AxisOperation;
-import org.apache.axis.description.AxisService;
-import org.apache.axis.description.AxisTransportIn;
-import org.apache.axis.description.AxisTransportOut;
+import org.apache.axis.context.ConfigurationContext;
+import org.apache.axis.description.GlobalDescription;
+import org.apache.axis.description.OperationDescription;
+import org.apache.axis.description.ServiceDescription;
+import org.apache.axis.description.TransportInDescription;
+import org.apache.axis.description.TransportOutDescription;
 import org.apache.axis.handlers.AbstractHandler;
 import org.apache.axis.om.OMAbstractFactory;
 import org.apache.axis.om.SOAPFactory;
@@ -38,7 +38,7 @@
   
     private QName serviceName = new QName("NullService");
     private QName operationName = new QName("DummyOp");
-    private SystemContext engineContext;
+    private ConfigurationContext engineContext;
 
     public EnginePausingTest() {
     }
@@ -47,23 +47,23 @@
         super(arg0);
     }
     protected void setUp() throws Exception {
-        engineRegistry = new AxisSystemImpl(new AxisGlobal());
+        engineRegistry = new AxisSystemImpl(new GlobalDescription());
 
-        AxisTransportOut transportOut = new AxisTransportOut(new QName("null"));
+        TransportOutDescription transportOut = new TransportOutDescription(new QName("null"));
         transportOut.setSender(new NullTransportSender());
 
-        AxisTransportIn transportIn = new AxisTransportIn(new QName("null"));
+        TransportInDescription transportIn = new TransportInDescription(new QName("null"));
         
-        engineContext = new SystemContext(engineRegistry);
+        engineContext = new ConfigurationContext(engineRegistry);
 
-        AxisOperation axisOp = new AxisOperation(operationName);
+        OperationDescription axisOp = new OperationDescription(operationName);
         mc = new MessageContext(engineContext, null, transportIn,transportOut,OperationContextFactory.createMEPContext(WSDLConstants.MEP_CONSTANT_IN_OUT,false,axisOp,null));
 
         mc.setTransportOut(transportOut);
         mc.setServerSide(true);
         SOAPFactory omFac = OMAbstractFactory.getSOAP11Factory();
         mc.setEnvelope(omFac.getDefaultEnvelope());
-        AxisService service = new AxisService(serviceName);
+        ServiceDescription service = new ServiceDescription(serviceName);
         axisOp.setMessageReciever(new NullMessageReceiver());
         
 

Modified: webservices/axis/trunk/java/modules/core/test/org/apache/axis/engine/EngineWithoutPhaseResolvingTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test/org/apache/axis/engine/EngineWithoutPhaseResolvingTest.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test/org/apache/axis/engine/EngineWithoutPhaseResolvingTest.java (original)
+++ webservices/axis/trunk/java/modules/core/test/org/apache/axis/engine/EngineWithoutPhaseResolvingTest.java Thu May 12 05:32:55 2005
@@ -24,12 +24,13 @@
 import org.apache.axis.addressing.EndpointReference;
 import org.apache.axis.context.MessageContext;
 import org.apache.axis.context.OperationContextFactory;
-import org.apache.axis.context.SystemContext;
-import org.apache.axis.description.AxisGlobal;
-import org.apache.axis.description.AxisOperation;
-import org.apache.axis.description.AxisService;
-import org.apache.axis.description.AxisTransportIn;
-import org.apache.axis.description.AxisTransportOut;
+import org.apache.axis.context.ServiceContext;
+import org.apache.axis.context.ConfigurationContext;
+import org.apache.axis.description.GlobalDescription;
+import org.apache.axis.description.OperationDescription;
+import org.apache.axis.description.ServiceDescription;
+import org.apache.axis.description.TransportInDescription;
+import org.apache.axis.description.TransportOutDescription;
 import org.apache.axis.om.OMAbstractFactory;
 import org.apache.axis.om.SOAPFactory;
 import org.apache.wsdl.WSDLConstants;
@@ -38,11 +39,11 @@
 public class EngineWithoutPhaseResolvingTest extends AbstractEngineTest {
     private MessageContext mc;
     private ArrayList executedHandlers = new ArrayList();
-    private AxisSystem engineRegistry;
+    private AxisConfiguration engineRegistry;
     private QName serviceName = new QName("axis/services/NullService");
     private QName opearationName = new QName("NullOperation");
-    private AxisService service;
-    private SystemContext engineContext;
+    private ServiceDescription service;
+    private ConfigurationContext engineContext;
 
     public EngineWithoutPhaseResolvingTest() {
     }
@@ -52,13 +53,22 @@
     }
     protected void setUp() throws Exception {
 
-        engineRegistry = new AxisSystemImpl(new AxisGlobal());
-        engineContext = new SystemContext(engineRegistry);
-        AxisTransportOut transport = new AxisTransportOut(new QName("null"));
+        engineRegistry = new AxisSystemImpl(new GlobalDescription());
+        engineContext = new ConfigurationContext(engineRegistry);
+
+        TransportOutDescription transport = new TransportOutDescription(new QName("null"));
         transport.setSender(new NullTransportSender());
 
-        AxisTransportIn transportIn = new AxisTransportIn(new QName("null"));
-        AxisOperation axisOp = new AxisOperation(opearationName);
+        TransportInDescription transportIn = new TransportInDescription(new QName("null"));
+        OperationDescription axisOp = new OperationDescription(opearationName);
+
+        service = new ServiceDescription(serviceName);
+        axisOp.setMessageReciever(new NullMessageReceiver());
+        engineRegistry.addService(service);
+        service.setStyle(WSDLService.STYLE_DOC);
+        service.addOperation(axisOp);
+
+        ServiceContext serviceContext = engineContext.createServiceContext(serviceName);
 
         mc =
             new MessageContext(
@@ -66,16 +76,11 @@
                null,
                 transportIn,
                 transport,
-        OperationContextFactory.createMEPContext(WSDLConstants.MEP_CONSTANT_IN_OUT,false,axisOp, null));
+        OperationContextFactory.createMEPContext(WSDLConstants.MEP_CONSTANT_IN_OUT,false,axisOp, serviceContext));
         mc.setTransportOut(transport);
         mc.setServerSide(true);
         SOAPFactory omFac = OMAbstractFactory.getSOAP11Factory();
         mc.setEnvelope(omFac.getDefaultEnvelope());
-        service = new AxisService(serviceName);
-        axisOp.setMessageReciever(new NullMessageReceiver());
-        engineRegistry.addService(service);
-        service.setStyle(WSDLService.STYLE_DOC);
-        service.addOperation(axisOp);
 
         mc.setTo(new EndpointReference(AddressingConstants.WSA_TO, "axis/services/NullService"));
         mc.setWSAAction(opearationName.getLocalPart());

Modified: webservices/axis/trunk/java/modules/core/test/org/apache/axis/engine/MessageContextTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test/org/apache/axis/engine/MessageContextTest.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test/org/apache/axis/engine/MessageContextTest.java (original)
+++ webservices/axis/trunk/java/modules/core/test/org/apache/axis/engine/MessageContextTest.java Thu May 12 05:32:55 2005
@@ -19,8 +19,8 @@
 import org.apache.axis.AbstractTestCase;
 import org.apache.axis.context.MessageContext;
 import org.apache.axis.context.OperationContextFactory;
-import org.apache.axis.context.SystemContext;
-import org.apache.axis.description.AxisGlobal;
+import org.apache.axis.context.ConfigurationContext;
+import org.apache.axis.description.GlobalDescription;
 import org.apache.axis.om.OMAbstractFactory;
 import org.apache.axis.om.SOAPFactory;
 import org.apache.wsdl.WSDLConstants;
@@ -31,8 +31,8 @@
     }
 
     public void testMesssageContext() throws AxisFault {
-        AxisSystem er = new AxisSystemImpl(new AxisGlobal());
-        SystemContext engineContext = new SystemContext(er);
+        AxisConfiguration er = new AxisSystemImpl(new GlobalDescription());
+        ConfigurationContext engineContext = new ConfigurationContext(er);
         MessageContext msgctx =
             new MessageContext(
                 engineContext,

Modified: webservices/axis/trunk/java/modules/core/test/org/apache/axis/phaserule/InvalidPhaseRuleTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test/org/apache/axis/phaserule/InvalidPhaseRuleTest.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test/org/apache/axis/phaserule/InvalidPhaseRuleTest.java (original)
+++ webservices/axis/trunk/java/modules/core/test/org/apache/axis/phaserule/InvalidPhaseRuleTest.java Thu May 12 05:32:55 2005
@@ -5,10 +5,10 @@
 import javax.xml.namespace.QName;
 
 import org.apache.axis.AbstractTestCase;
-import org.apache.axis.description.AxisGlobal;
-import org.apache.axis.description.HandlerMetadata;
+import org.apache.axis.description.GlobalDescription;
+import org.apache.axis.description.HandlerDescription;
 import org.apache.axis.description.PhaseRule;
-import org.apache.axis.engine.AxisSystem;
+import org.apache.axis.engine.AxisConfiguration;
 import org.apache.axis.engine.AxisSystemImpl;
 import org.apache.axis.engine.Handler;
 import org.apache.axis.phaseresolver.PhaseHolder;
@@ -39,7 +39,7 @@
 public class InvalidPhaseRuleTest extends AbstractTestCase {
 
     InvalidPhaseRuleTest phaserul;
-    AxisSystem registry;
+    AxisConfiguration registry;
 
     public InvalidPhaseRuleTest(String testName) {
         super(testName);
@@ -49,7 +49,7 @@
         try {
             super.setUp();
             phaserul = new InvalidPhaseRuleTest("");
-            AxisGlobal global = new AxisGlobal();
+            GlobalDescription global = new GlobalDescription();
             registry = new AxisSystemImpl(global);
             ArrayList inPhase = new ArrayList();
 
@@ -65,7 +65,7 @@
             ph.setFlowType(1);
 
 
-            HandlerMetadata hm = new HandlerMetadata();
+            HandlerDescription hm = new HandlerDescription();
             hm.setClassName("org.apache.axis.handlers.AbstractHandler");
             hm.setHandler(han);
             hm.setName(new QName("H1"));
@@ -75,7 +75,7 @@
             hm.setRules(rule);
             ph.addHandler(hm);
 
-            HandlerMetadata hm1 = new HandlerMetadata();
+            HandlerDescription hm1 = new HandlerDescription();
             hm1.setClassName("org.apache.axis.handlers.AbstractHandler");
             hm1.setHandler(han);
             hm1.setName(new QName("H2"));
@@ -85,7 +85,7 @@
             hm1.setRules(rule1);
             ph.addHandler(hm1);
 
-            HandlerMetadata hm3 = new HandlerMetadata();
+            HandlerDescription hm3 = new HandlerDescription();
             hm3.setClassName("org.apache.axis.handlers.AbstractHandler");
             hm3.setHandler(han);
             hm3.setName(new QName("H4"));
@@ -97,7 +97,7 @@
 
             ArrayList oh = ph.getOrderHandler();
             for (int i = 0; i < oh.size(); i++) {
-                HandlerMetadata metadata = (HandlerMetadata) oh.get(i);
+                HandlerDescription metadata = (HandlerDescription) oh.get(i);
                 System.out.println("Name:" + metadata.getName().getLocalPart());
             }
             fail("this must failed gracefully with PhaseException ");
@@ -111,7 +111,7 @@
         try {
             super.setUp();
             phaserul = new InvalidPhaseRuleTest("");
-            AxisGlobal global = new AxisGlobal();
+            GlobalDescription global = new GlobalDescription();
             registry = new AxisSystemImpl(global);
             ArrayList inPhase = new ArrayList();
 
@@ -127,7 +127,7 @@
             ph.setFlowType(1);
 
 
-            HandlerMetadata hm = new HandlerMetadata();
+            HandlerDescription hm = new HandlerDescription();
             hm.setClassName("org.apache.axis.handlers.AbstractHandler");
             hm.setHandler(han);
             hm.setName(new QName("H1"));
@@ -138,7 +138,7 @@
             hm.setRules(rule);
             ph.addHandler(hm);
 
-            HandlerMetadata hm1 = new HandlerMetadata();
+            HandlerDescription hm1 = new HandlerDescription();
             hm1.setClassName("org.apache.axis.handlers.AbstractHandler");
             hm1.setHandler(han);
             hm1.setName(new QName("H2"));
@@ -148,7 +148,7 @@
             hm1.setRules(rule1);
             ph.addHandler(hm1);
 
-            HandlerMetadata hm3 = new HandlerMetadata();
+            HandlerDescription hm3 = new HandlerDescription();
             hm3.setClassName("org.apache.axis.handlers.AbstractHandler");
             hm3.setHandler(han);
             hm3.setName(new QName("H4"));
@@ -160,7 +160,7 @@
 
             ArrayList oh = ph.getOrderHandler();
             for (int i = 0; i < oh.size(); i++) {
-                HandlerMetadata metadata = (HandlerMetadata) oh.get(i);
+                HandlerDescription metadata = (HandlerDescription) oh.get(i);
                 System.out.println("Name:" + metadata.getName().getLocalPart());
             }
             fail("this must failed gracefully with PhaseException ");

Modified: webservices/axis/trunk/java/modules/core/test/org/apache/axis/phaserule/PhaseRuleTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test/org/apache/axis/phaserule/PhaseRuleTest.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test/org/apache/axis/phaserule/PhaseRuleTest.java (original)
+++ webservices/axis/trunk/java/modules/core/test/org/apache/axis/phaserule/PhaseRuleTest.java Thu May 12 05:32:55 2005
@@ -5,10 +5,10 @@
 import javax.xml.namespace.QName;
 
 import org.apache.axis.AbstractTestCase;
-import org.apache.axis.description.AxisGlobal;
-import org.apache.axis.description.HandlerMetadata;
+import org.apache.axis.description.GlobalDescription;
+import org.apache.axis.description.HandlerDescription;
 import org.apache.axis.description.PhaseRule;
-import org.apache.axis.engine.AxisSystem;
+import org.apache.axis.engine.AxisConfiguration;
 import org.apache.axis.engine.AxisSystemImpl;
 import org.apache.axis.engine.Handler;
 import org.apache.axis.phaseresolver.PhaseHolder;
@@ -22,7 +22,7 @@
 public class PhaseRuleTest extends AbstractTestCase {
 
     PhaseRuleTest phaserul;
-    AxisSystem registry;
+    AxisConfiguration registry;
 
     public PhaseRuleTest(String testName) {
         super(testName);
@@ -31,7 +31,7 @@
     public void testPhaseRules() throws Exception {
         super.setUp();
         phaserul = new PhaseRuleTest("");
-        AxisGlobal global = new AxisGlobal();
+        GlobalDescription global = new GlobalDescription();
         registry = new AxisSystemImpl(global);
         ArrayList inPhase = new ArrayList();
 
@@ -48,7 +48,7 @@
         PhaseHolder ph = new PhaseHolder(registry);
         ph.setFlowType(1);
 
-        HandlerMetadata hm = new HandlerMetadata();
+        HandlerDescription hm = new HandlerDescription();
         hm.setClassName("org.apache.axis.handlers.AbstractHandler");
         hm.setHandler(han);
         hm.setName(new QName("H1"));
@@ -58,7 +58,7 @@
         hm.setRules(rule);
         ph.addHandler(hm);
 
-        HandlerMetadata hm1 = new HandlerMetadata();
+        HandlerDescription hm1 = new HandlerDescription();
         hm1.setClassName("org.apache.axis.handlers.AbstractHandler");
         hm1.setHandler(han);
         hm1.setName(new QName("H2"));
@@ -68,7 +68,7 @@
         hm1.setRules(rule1);
         ph.addHandler(hm1);
 
-        HandlerMetadata hm2 = new HandlerMetadata();
+        HandlerDescription hm2 = new HandlerDescription();
         hm2.setClassName("org.apache.axis.handlers.AbstractHandler");
         hm2.setHandler(han);
         hm2.setName(new QName("H3"));
@@ -79,7 +79,7 @@
         hm2.setRules(rule2);
         ph.addHandler(hm2);
 
-        HandlerMetadata hm3 = new HandlerMetadata();
+        HandlerDescription hm3 = new HandlerDescription();
         hm3.setClassName("org.apache.axis.handlers.AbstractHandler");
         hm3.setHandler(han);
         hm3.setName(new QName("H4"));
@@ -91,7 +91,7 @@
 
         ArrayList oh = ph.getOrderHandler();
         for (int i = 0; i < oh.size(); i++) {
-            HandlerMetadata metadata = (HandlerMetadata) oh.get(i);
+            HandlerDescription metadata = (HandlerDescription) oh.get(i);
             System.out.println("Name:" + metadata.getName().getLocalPart());
         }
     }

Modified: webservices/axis/trunk/java/modules/core/test/org/apache/axis/phaserule/PreDispatchPhaseRuleTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test/org/apache/axis/phaserule/PreDispatchPhaseRuleTest.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test/org/apache/axis/phaserule/PreDispatchPhaseRuleTest.java (original)
+++ webservices/axis/trunk/java/modules/core/test/org/apache/axis/phaserule/PreDispatchPhaseRuleTest.java Thu May 12 05:32:55 2005
@@ -5,10 +5,10 @@
 import javax.xml.namespace.QName;
 
 import org.apache.axis.AbstractTestCase;
-import org.apache.axis.description.AxisGlobal;
-import org.apache.axis.description.HandlerMetadata;
+import org.apache.axis.description.GlobalDescription;
+import org.apache.axis.description.HandlerDescription;
 import org.apache.axis.description.PhaseRule;
-import org.apache.axis.engine.AxisSystem;
+import org.apache.axis.engine.AxisConfiguration;
 import org.apache.axis.engine.AxisSystemImpl;
 import org.apache.axis.engine.Handler;
 import org.apache.axis.phaseresolver.PhaseHolder;
@@ -39,7 +39,7 @@
 public class PreDispatchPhaseRuleTest  extends AbstractTestCase{
 
     PreDispatchPhaseRuleTest phaserul;
-    AxisSystem registry;
+    AxisConfiguration registry;
 
     public PreDispatchPhaseRuleTest(String testName) {
         super(testName);
@@ -47,7 +47,7 @@
 
     public void testPhaseRule() throws Exception {
         phaserul = new PreDispatchPhaseRuleTest("");
-        AxisGlobal global = new AxisGlobal();
+        GlobalDescription global = new GlobalDescription();
         registry = new AxisSystemImpl(global);
         ArrayList inPhase = new ArrayList();
 
@@ -65,7 +65,7 @@
         ph.setFlowType(1);
 
 
-        HandlerMetadata pre = new HandlerMetadata();
+        HandlerDescription pre = new HandlerDescription();
         pre.setClassName("org.apache.axis.handlers.AbstractHandler");
         pre.setHandler(han);
         pre.setName(new QName("pre-H1"));
@@ -74,7 +74,7 @@
         pre.setRules(pre_rule1);
         ph.addHandler(pre);
 
-        HandlerMetadata pre2 = new HandlerMetadata();
+        HandlerDescription pre2 = new HandlerDescription();
         pre2.setClassName("org.apache.axis.handlers.AbstractHandler");
         pre2.setHandler(han);
         pre2.setName(new QName("pre-H2"));
@@ -84,7 +84,7 @@
         ph.addHandler(pre2);
 
 
-        HandlerMetadata hm = new HandlerMetadata();
+        HandlerDescription hm = new HandlerDescription();
         hm.setClassName("org.apache.axis.handlers.AbstractHandler");
         hm.setHandler(han);
         hm.setName(new QName("H1"));
@@ -94,7 +94,7 @@
         hm.setRules(rule);
         ph.addHandler(hm);
 
-        HandlerMetadata hm1 = new HandlerMetadata();
+        HandlerDescription hm1 = new HandlerDescription();
         hm1.setClassName("org.apache.axis.handlers.AbstractHandler");
         hm1.setHandler(han);
         hm1.setName(new QName("H2"));
@@ -104,7 +104,7 @@
         hm1.setRules(rule1);
         ph.addHandler(hm1);
 
-        HandlerMetadata hm2 = new HandlerMetadata();
+        HandlerDescription hm2 = new HandlerDescription();
         hm2.setClassName("org.apache.axis.handlers.AbstractHandler");
         hm2.setHandler(han);
         hm2.setName(new QName("H3"));
@@ -115,7 +115,7 @@
         hm2.setRules(rule2);
         ph.addHandler(hm2);
 
-        HandlerMetadata hm3 = new HandlerMetadata();
+        HandlerDescription hm3 = new HandlerDescription();
         hm3.setClassName("org.apache.axis.handlers.AbstractHandler");
         hm3.setHandler(han);
         hm3.setName(new QName("H4"));
@@ -127,7 +127,7 @@
 
         ArrayList oh = ph.getOrderHandler();
         for (int i = 0; i < oh.size(); i++) {
-            HandlerMetadata metadata = (HandlerMetadata) oh.get(i);
+            HandlerDescription metadata = (HandlerDescription) oh.get(i);
             System.out.println("Name:" + metadata.getName().getLocalPart());
         }
     }

Modified: webservices/axis/trunk/java/modules/samples/src/encoding/sample1/EchoProvider.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/samples/src/encoding/sample1/EchoProvider.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/samples/src/encoding/sample1/EchoProvider.java (original)
+++ webservices/axis/trunk/java/modules/samples/src/encoding/sample1/EchoProvider.java Thu May 12 05:32:55 2005
@@ -87,7 +87,7 @@
 //			
 //			//find the WebService method  
 //			Class ImplClass = obj.getClass();
-//            AxisOperation op = msgContext.getOperationContext().getAxisOperation();
+//            OperationDescription op = msgContext.getOperationContext().getAxisOperation();
 //			String methodName = op.getName().getLocalPart();
 //			
 //			

Modified: webservices/axis/trunk/java/modules/samples/src/encoding/sample2/benchMark/BenchProvider.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/samples/src/encoding/sample2/benchMark/BenchProvider.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/samples/src/encoding/sample2/benchMark/BenchProvider.java (original)
+++ webservices/axis/trunk/java/modules/samples/src/encoding/sample2/benchMark/BenchProvider.java Thu May 12 05:32:55 2005
@@ -22,7 +22,7 @@
 import javax.xml.stream.XMLStreamReader;
 
 import org.apache.axis.context.MessageContext;
-import org.apache.axis.description.AxisOperation;
+import org.apache.axis.description.OperationDescription;
 import org.apache.axis.engine.AxisFault;
 import org.apache.axis.om.OMAbstractFactory;
 import org.apache.axis.om.OMConstants;
@@ -106,7 +106,7 @@
 
 			//find the WebService method
 			Class ImplClass = obj.getClass();
-            AxisOperation op = msgContext.getOperationContext().getAxisOperation();
+            OperationDescription op = msgContext.getOperationContext().getAxisOperation();
 			String methodName = op.getName().getLocalPart();
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseResolver.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseResolver.java Thu May 12 05:32:55 2005
@@ -23,17 +23,17 @@
 
 import javax.xml.namespace.QName;
 
-import org.apache.axis.context.SystemContext;
-import org.apache.axis.description.AxisGlobal;
-import org.apache.axis.description.AxisModule;
-import org.apache.axis.description.AxisOperation;
-import org.apache.axis.description.AxisService;
-import org.apache.axis.description.AxisTransportIn;
-import org.apache.axis.description.AxisTransportOut;
+import org.apache.axis.context.ConfigurationContext;
+import org.apache.axis.description.GlobalDescription;
+import org.apache.axis.description.ModuleDescription;
+import org.apache.axis.description.OperationDescription;
+import org.apache.axis.description.ServiceDescription;
+import org.apache.axis.description.TransportInDescription;
+import org.apache.axis.description.TransportOutDescription;
 import org.apache.axis.description.Flow;
-import org.apache.axis.description.HandlerMetadata;
+import org.apache.axis.description.HandlerDescription;
 import org.apache.axis.engine.AxisFault;
-import org.apache.axis.engine.AxisSystem;
+import org.apache.axis.engine.AxisConfiguration;
 import org.apache.axis.engine.AxisSystemImpl;
 
 /**
@@ -43,12 +43,12 @@
     /**
      * Field engineConfig
      */
-    private final AxisSystem engineConfig;
+    private final AxisConfiguration engineConfig;
 
     /**
      * Field axisService
      */
-    private AxisService axisService;
+    private ServiceDescription axisService;
 
 
     /**
@@ -57,11 +57,11 @@
     private PhaseHolder phaseHolder;
 
     /**
      * default constructor , to obuild chains for AxisGlobal
      *
      * @param engineConfig
      */
-    public PhaseResolver(AxisSystem engineConfig) {
+    public PhaseResolver(AxisConfiguration engineConfig) {
         this.engineConfig = engineConfig;
     }
 
@@ -71,8 +71,8 @@
      * @param engineConfig
      * @param serviceContext
      */
-    public PhaseResolver(AxisSystem engineConfig,
-                         AxisService serviceContext) {
+    public PhaseResolver(AxisConfiguration engineConfig,
+                         ServiceDescription serviceContext) {
         this.engineConfig = engineConfig;
         this.axisService = serviceContext;
     }
@@ -87,14 +87,14 @@
         HashMap operations = axisService.getOperations();
         Collection col = operations.values();
         for (Iterator iterator = col.iterator(); iterator.hasNext();) {
-            AxisOperation operation = (AxisOperation) iterator.next();
+            OperationDescription operation = (OperationDescription) iterator.next();
             for (int i = 1; i < 5; i++) {
                 buildExcutionChains(i, operation);
             }
         }
     }
 
-    private void buildModuleHandlers(ArrayList allHandlers, AxisModule module, int flowtype) throws PhaseException {
+    private void buildModuleHandlers(ArrayList allHandlers, ModuleDescription module, int flowtype) throws PhaseException {
         Flow flow = null;
         switch (flowtype) {
             case PhaseMetadata.IN_FLOW:
@@ -120,7 +120,7 @@
         }
         if (flow != null) {
             for (int j = 0; j < flow.getHandlerCount(); j++) {
-                HandlerMetadata metadata = flow.getHandler(j);
+                HandlerDescription metadata = flow.getHandler(j);
                 /**
                  * If the phase property of a handler is pre-dispatch then those handlers
                  * should go to the global chain , to the pre-dispatch phase
@@ -147,11 +147,11 @@
      * @throws AxisFault
      * @throws PhaseException
      */
-    private void buildExcutionChains(int type, AxisOperation operation)
+    private void buildExcutionChains(int type, OperationDescription operation)
             throws AxisFault, PhaseException {
         int flowtype = type;
         ArrayList allHandlers = new ArrayList();
-        AxisModule module;
+        ModuleDescription module;
         Flow flow = null;
         ArrayList modules = (ArrayList) axisService.getModules();
         ///////////////////////////////////////////////////////////////////////////////////////
@@ -194,7 +194,7 @@
         }
         if (flow != null) {
             for (int j = 0; j < flow.getHandlerCount(); j++) {
-                HandlerMetadata metadata = flow.getHandler(j);
+                HandlerDescription metadata = flow.getHandler(j);
 
                 // todo change this in properway
                 if (metadata.getRules().getPhaseName().equals("")) {
@@ -230,8 +230,8 @@
         phaseHolder = new PhaseHolder(engineConfig, operation);
         phaseHolder.setFlowType(flowtype);
         for (int i = 0; i < allHandlers.size(); i++) {
-            HandlerMetadata handlerMetaData =
-                    (HandlerMetadata) allHandlers.get(i);
+            HandlerDescription handlerMetaData =
+                    (HandlerDescription) allHandlers.get(i);
             phaseHolder.addHandler(handlerMetaData);
         }
         phaseHolder.getOrderedHandlers(type);
@@ -249,20 +249,20 @@
         Collection colintrnsport = axisTransportIn.values();
         for (Iterator iterator = colintrnsport.iterator();
              iterator.hasNext();) {
-            AxisTransportIn transport = (AxisTransportIn) iterator.next();
+            TransportInDescription transport = (TransportInDescription) iterator.next();
             buildINTransportChains(transport);
         }
 
         Collection colouttrnsport = axisTransportOut.values();
         for (Iterator iterator = colouttrnsport.iterator();
              iterator.hasNext();) {
-            AxisTransportOut transport = (AxisTransportOut) iterator.next();
+            TransportOutDescription transport = (TransportOutDescription) iterator.next();
             buildOutTransportChains(transport);
         }
     }
 
 
-    private void buildINTransportChains(AxisTransportIn transport)
+    private void buildINTransportChains(TransportInDescription transport)
             throws PhaseException {
         Flow flow = null;
         for (int type = 1; type < 4; type++) {
@@ -282,7 +282,7 @@
             }
             if (flow != null) {
                 for (int j = 0; j < flow.getHandlerCount(); j++) {
-                    HandlerMetadata metadata = flow.getHandler(j);
+                    HandlerDescription metadata = flow.getHandler(j);
 
                     // todo change this in properway
                     if (metadata.getRules().getPhaseName().equals("")) {
@@ -302,7 +302,7 @@
      * @param transport
      * @throws PhaseException
      */
-    private void buildOutTransportChains(AxisTransportOut transport)
+    private void buildOutTransportChains(TransportOutDescription transport)
             throws PhaseException {
         Flow flow = null;
         for (int type = 1; type < 4; type++) {
@@ -322,7 +322,7 @@
             }
             if (flow != null) {
                 for (int j = 0; j < flow.getHandlerCount(); j++) {
-                    HandlerMetadata metadata = flow.getHandler(j);
+                    HandlerDescription metadata = flow.getHandler(j);
 
                     // todo change this in properway
                     if (metadata.getRules().getPhaseName().equals("")) {
@@ -341,21 +341,21 @@
      * @throws AxisFault
      * @throws PhaseException
      */
-    public SystemContext buildGlobalChains()
+    public ConfigurationContext buildGlobalChains()
             throws AxisFault, PhaseException {
-        SystemContext engineContext = new SystemContext(engineConfig);
-        AxisGlobal global = engineConfig.getGlobal();
+        ConfigurationContext engineContext = new ConfigurationContext(engineConfig);
+        GlobalDescription global = engineConfig.getGlobal();
         List modules = (List) global.getModules();
         int count = modules.size();
         QName moduleName;
-        AxisModule module;
+        ModuleDescription module;
         Flow flow = null;
         for (int type = 1; type < 5; type++) {
             phaseHolder = new PhaseHolder(engineConfig);
             phaseHolder.setFlowType(type);
             Collection col = ((AxisSystemImpl) engineConfig).getModules().values();
             for (Iterator iterator = col.iterator(); iterator.hasNext();) {
-                AxisModule axismodule = (AxisModule) iterator.next();
+                ModuleDescription axismodule = (ModuleDescription) iterator.next();
                 switch (type) {
                     case PhaseMetadata.IN_FLOW:
                         {
@@ -380,7 +380,7 @@
                 }
                 if (flow != null) {
                     for (int j = 0; j < flow.getHandlerCount(); j++) {
-                        HandlerMetadata metadata = flow.getHandler(j);
+                        HandlerDescription metadata = flow.getHandler(j);
                         /**
                          * If the phase property of a handler is pre-dispatch then those handlers
                          * should go to the global chain , to the pre-dispatch phase
@@ -421,7 +421,7 @@
                 }
                 if (flow != null) {
                     for (int j = 0; j < flow.getHandlerCount(); j++) {
-                        HandlerMetadata metadata = flow.getHandler(j);
+                        HandlerDescription metadata = flow.getHandler(j);
                         if (!PhaseMetadata.PRE_DISPATCH.equals(metadata.getRules().getPhaseName())) {
                             phaseHolder.addHandler(metadata);
                         } else {
@@ -57,11 +57,11 @@
 
     /**
-     * default constructor , to obuild chains for AxisGlobal
+     * default constructor , to obuild chains for GlobalDescription
      *
      * @param engineConfig

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/receivers/AbstractMessageReceiver.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/receivers/AbstractMessageReceiver.java?rev=169807&r1=169806&r2=169807&view=diff
==============================================================================